@@ -13,7 +13,9 @@ else:
         return isinstance(field, HiddenField)
 
 
-def bootstrap_find_resource(filename, use_minified=None):
+def bootstrap_find_resource(filename,
+                            use_minified=None,
+                            cdn='bootstrap'):
     # FIXME: get rid of this function and instead manipulate the flask routing
     #        system
     config = current_app.config
@@ -27,7 +29,8 @@ def bootstrap_find_resource(filename, use_minified=None):
     if not config['BOOTSTRAP_USE_CDN']:
         return url_for('bootstrap.static', filename=filename)
     else:
-        baseurl = config['BOOTSTRAP_CDN_BASEURL']
+        baseurl = config['BOOTSTRAP_CDN_BASEURL'][cdn]
+
         if baseurl.startswith('//') and config['BOOTSTRAP_CDN_PREFER_SSL']:
             baseurl = 'https:%s' % baseurl
         return baseurl + filename
@@ -45,20 +48,24 @@ class Bootstrap(object):
         app.config.setdefault('BOOTSTRAP_GOOGLE_ANALYTICS_ACCOUNT', None)
         app.config.setdefault('BOOTSTRAP_USE_CDN', False)
         app.config.setdefault('BOOTSTRAP_CDN_PREFER_SSL', True)
+        app.config.setdefault('BOOTSTRAP_FONTAWESOME', False)
         app.config.setdefault(
-            'BOOTSTRAP_CDN_BASEURL',
-            '//netdna.bootstrapcdn.com/twitter-bootstrap/2.1.1/'
+            'BOOTSTRAP_CDN_BASEURL', {
+                'bootstrap':   '//netdna.bootstrapcdn.com/'\
+                               'twitter-bootstrap/2.2.1/',
+                'fontawesome': '//netdna.bootstrapcdn.com/'\
+                               'font-awesome/2.0/',
+            }
         )
 
-        self.app = app
-        self.blueprint = Blueprint(
+        blueprint = Blueprint(
             'bootstrap',
             __name__,
             template_folder='templates',
             static_folder='static',
-            static_url_path=self.app.static_url_path + '/bootstrap')
+            static_url_path=app.static_url_path + '/bootstrap')
 
-        app.register_blueprint(self.blueprint)
+        app.register_blueprint(blueprint)
 
         app.jinja_env.filters['bootstrap_is_hidden_field'] =\
             is_hidden_field_filter
